==> mame_0.154.orig.tar.xz: mame-0.154/src/mame/machine/pgmcrypt.h <==
/* IGS 027 Encryptions */

void pgm_kov_decrypt(running_machine &machine);
void pgm_kovsh_decrypt(running_machine &machine);
void pgm_kov2_decrypt(running_machine &machine);
void pgm_kov2p_decrypt(running_machine &machine);
void pgm_mm_decrypt(running_machine &machine);
void pgm_photoy2k_decrypt(running_machine &machine);
void pgm_py2k2_decrypt(running_machine &machine);
void pgm_pstar_decrypt(running_machine &machine);
void pgm_puzzli2_decrypt(running_machine &machine);
void pgm_theglad_decrypt(running_machine &machine);
void pgm_ddp2_decrypt(running_machine &machine);
void pgm_dfront_decrypt(running_machine &machine);
void pgm_oldsplus_decrypt(running_machine &machine);
void pgm_kovshp_decrypt(running_machine &machine);
void pgm_killbldp_decrypt(running_machine &machine);
void pgm_svg_decrypt(running_machine &machine);
void pgm_svgpcb_decrypt(running_machine &machine);
void pgm_ket_decrypt(running_machine &machine);
void pgm_espgal_decrypt(running_machine &machine);
void pgm_happy6_decrypt(running_machine &machine);
void sdwx_decrypt(running_machine &machine);
void hauntedh_decrypt(running_machine &machine);
void chessc2_decrypt(running_machine &machine);
void klxyj_decrypt(running_machine &machine);
void big2_decrypt(running_machine &machine);
void gonefsh2_decrypt(running_machine &machine);
void sddz_decrypt(running_machine &machine);
void lhzb3_decrypt(running_machine &machine);
void mgfx_decrypt(running_machine &machine);
void lhzb4_decrypt(running_machine &machine);
void fearless_decrypt(running_machine &machine);
void pgm_decrypt_pgm3in1(running_machine &machine);

==> mame_0.189+dfsg.1.orig.tar.xz: mame-0.189+dfsg.1/src/mame/machine/pgmcrypt.h <==
// license:BSD-3-Clause
// copyright-holders:David Haywood, ElSemi
/* IGS 027 Encryptions */

void pgm_kov_decrypt(running_machine &machine);
void pgm_kovsh_decrypt(running_machine &machine);
void pgm_kov2_decrypt(running_machine &machine);
void pgm_kov2p_decrypt(running_machine &machine);
void pgm_mm_decrypt(running_machine &machine);
void pgm_photoy2k_decrypt(running_machine &machine);
void pgm_py2k2_decrypt(running_machine &machine);
void pgm_pstar_decrypt(running_machine &machine);
void pgm_puzzli2_decrypt(running_machine &machine);
void pgm_theglad_decrypt(running_machine &machine);
void pgm_ddp2_decrypt(running_machine &machine);
void pgm_dfront_decrypt(running_machine &machine);
void pgm_oldsplus_decrypt(running_machine &machine);
void pgm_kovshp_decrypt(running_machine &machine);
void pgm_killbldp_decrypt(running_machine &machine);
void pgm_svg_decrypt(running_machine &machine);
void pgm_svgpcb_decrypt(running_machine &machine);
void pgm_ket_decrypt(running_machine &machine);
void pgm_espgal_decrypt(running_machine &machine);
void pgm_happy6_decrypt(running_machine &machine);
void sdwx_decrypt(running_machine &machine);
void hauntedh_decrypt(running_machine &machine);
void chessc2_decrypt(running_machine &machine);
void klxyj_decrypt(running_machine &machine);
void zhongguo_decrypt(running_machine &machine);
void gonefsh2_decrypt(running_machine &machine);
void sddz_decrypt(running_machine &machine);
void lhzb3_decrypt(running_machine &machine);
void mgfx_decrypt(running_machine &machine);
void lhzb4_decrypt(running_machine &machine);
void fearless_decrypt(running_machine &machine);
void pgm_decrypt_pgm3in1(running_machine &machine);
void slqz3_decrypt(running_machine &machine);
void fruitpar_decrypt(running_machine &machine);
void amazonia_decrypt(running_machine &machine);
void amazoni2_decrypt(running_machine &machine);
